==> deepin-fcitx5configtool-plugin_6.0.8.tar.xz: BUILD/src/dcc-fcitx5configtool/translations/fcitx5configtool_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="14"/>
        <source>Advanced Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="28"/>
        <source>&quot;Advanced Settings&quot; is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
        <source>Global Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="52"/>
        <source>Add-ons</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="126"/>
        <source>Please enter a new shortcut</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="54"/>
        <source>Move Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="61"/>
        <source>Move Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="69"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="76"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="29"/>
        <source>Add input method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="37"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="102"/>
        <source>Find more in App Store</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="121"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="128"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="29"/>
        <source>Add input method</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="34"/>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="45"/>
        <source>Restore Defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="97"/>
        <source>Scroll between input methods</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="127"/>
        <source>Turn on or off input methods</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="131"/>
        <source>Please enter a new shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="156"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> deepin-fcitx5configtool-plugin_6.0.13.tar.xz: BUILD/src/dcc-fcitx5configtool/translations/fcitx5configtool_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation>Complementos</translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="14"/>
        <source>Advanced Settings</source>
        <translation>Ajustes avanzados</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="28"/>
        <source>&quot;Advanced Settings&quot; is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation>&quot;Ajustes avanzados&quot; sólo es válido para el método de entrada que utiliza los ajustes del sistema, si el método de entrada tiene sus propios ajustes, prevalecerán sus propios ajustes.</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
        <source>Global Config</source>
        <translation>Configuración global</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="52"/>
        <source>Add-ons</source>
        <translation>Complementos</translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="126"/>
        <source>Please enter a new shortcut</source>
        <translation>Introduzca un nuevo atajo</translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="54"/>
        <source>Move Up</source>
        <translation>Subir</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="61"/>
        <source>Move Down</source>
        <translation>Bajar</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="69"/>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="76"/>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="29"/>
        <source>Add input method</source>
        <translation>Añadir método de entrada</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="37"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="102"/>
        <source>Find more in App Store</source>
        <translation>Buscar más en la tienda</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="121"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="128"/>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation>Gestión del método de entrada</translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="29"/>
        <source>Add input method</source>
        <translation>Añadir método de entrada</translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="34"/>
        <source>Shortcuts</source>
        <translation>Atajos</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="45"/>
        <source>Restore Defaults</source>
        <translation>Restaurar valores predeterminados</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="97"/>
        <source>Scroll between input methods</source>
        <translation>Desplazarse entre métodos de entrada</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="127"/>
        <source>Turn on or off input methods</source>
        <translation>Activar o desactivar métodos de entrada</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="131"/>
        <source>Please enter a new shortcut</source>
        <translation>Introduzca un nuevo atajo</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="156"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation>Activa o desactiva el método de entrada utilizado actualmente. Si no se utiliza ningún método de entrada o el primer método de entrada no es el teclado, cambia entre el primer método de entrada y el teclado/método de entrada utilizado actualmente.</translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation>Método de entrada</translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation>Gestión del método de entrada, atajos del método de entrada, configuraciones avanzadas</translation>
    </message>
</context>
</TS>
